OC.L10N.register(
    "files",
    {
    "File could not be found" : "Fájl nem található",
    "Move or copy" : "Áthelyezés vagy másolás",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "Tags" : "Címkék",
    "Show list view" : "Listanézet megjelenítése",
    "Show grid view" : "Rácsnézet megjelenítése",
    "Home" : "Saját mappa",
    "Close" : "Bezárás",
    "Favorites" : "Kedvencek",
    "Could not create folder \"{dir}\"" : "A(z) „{dir}” mappa nem hozható létre",
    "This will stop your current uploads." : "Ez meg fogja állítani a jelenlegi feltöltéseket.",
    "Upload cancelled." : "Feltöltés megszakítva.",
    "Processing files …" : "Fájlok feldolgozása…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} fájl nem tölthető fel, mert vagy egy könyvtár, vagy 0 bájtos",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely, a feltöltés mérete {size1}, de csak {size2} hely van",
    "Target folder \"{dir}\" does not exist any more" : "A(z) „{dir}” célmappa már nem létezik",
    "Not enough free space" : "Nincs elég szabad hely",
    "An unknown error has occurred" : "Ismeretlen hiba történt",
    "File could not be uploaded" : "A fájlt nem lehetett feltölteni",
    "Uploading …" : "Feltöltés…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Ezen elem feltöltése nem támogatott",
    "Target folder does not exist any more" : "A célmappa már nem létezik",
    "Operation is blocked by access control" : "A hozzáférés-vezérlés letiltotta a műveletet",
    "Error when assembling chunks, status code {status}" : "Hiba a darabok összerakásakor, állapotkód: {status}",
    "Actions" : "Műveletek",
    "Rename" : "Átnevezés",
    "Move" : "Áthelyezés",
    "Copy" : "Másolás",
    "Choose target folder" : "Válasszon célmappát",
    "Edit locally" : "Szerkesztés helyileg",
    "Open" : "Megnyitás",
    "Delete file" : "Fájl törlése",
    "Delete folder" : "Mappa törlése",
    "Disconnect storage" : "Tároló leválasztása",
    "Leave this share" : "Megosztás elhagyása",
    "Could not load info for file \"{file}\"" : "Nem sikerült betölteni a(z) „{file}” fájl információit",
    "Files" : "Fájlok",
    "Details" : "Részletek",
    "Please select tag(s) to add to the selection" : "Válassza ki a kijelöléshez adandó címkéket",
    "Apply tag(s) to selection" : "Címkék alkalmazása a kijelölésre",
    "Select directory \"{dirName}\"" : "A(z) „{dirName}” könyvtár kiválasztása",
    "Select file \"{fileName}\"" : "A(z) „{fileName}” fájl kiválasztása",
    "Pending" : "Függőben",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "This operation is forbidden" : "Ez a művelet tiltott",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem érhető el, nézze meg a naplófájlokat vagy lépjen kapcsolatba az adminisztrátorral",
    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
    "Could not move \"{file}\", target exists" : "A(z) „{file}” nem helyezhető át, mert a cél már létezik",
    "Could not move \"{file}\"" : "A(z) „{file}” nem helyezhető át",
    "copy" : "másolat",
    "Could not copy \"{file}\", target exists" : "A(z) „{file}” másolása sikertelen, a cél már létezik",
    "Could not copy \"{file}\"" : "A(z) „{file}” másolása sikertelen",
    "Copied {origin} inside {destination}" : "A(z) {origin} átmásolva ide: {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "A(z) {origin} és {nbfiles} egyéb fájl átmásolva ide: {destination}",
    "Failed to redirect to client" : "Nem sikerült az átirányítás a klienshez",
    "{newName} already exists" : "A(z) {newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "A(z) „{fileName}” átnevetése sikertelen, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "A(z) „{targetName}” név már használatban van a(z) „{dir}” mappában. Válasszon másik nevet.",
    "Could not rename \"{fileName}\"" : "A(z) „{fileName}” nem nevezhető át",
    "Could not create file \"{file}\"" : "A(z) „{file}” nem hozható létre",
    "Could not create file \"{file}\" because it already exists" : "A(z) „{file}” fájl nem hozható létre, mert már létezik",
    "Could not create folder \"{dir}\" because it already exists" : "A(z) „{dir}” mappa nem hozható létre, mert már létezik",
    "Could not fetch file details \"{file}\"" : "A(z) „{file}” fájl részleteinek lekérése sikertelen",
    "Error deleting file \"{fileName}\"." : "Hiba történt a(z) „{fileName}” fájl törlése során.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ehhez nincsenek találatok más mappákban: {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Vigyen be legalább két karaktert a más mappákban való kereséshez",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n fájl","%n fájl"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "_including %n hidden_::_including %n hidden_" : ["köztük %n rejtett","köztük %n rejtett"],
    "You do not have permission to upload or create files here" : "Nincs jogosultsága fájlok ide feltöltéséhez vagy létrehozásához",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fájl feltöltése","%n fájl feltöltése"],
    "New file/folder menu" : "Új fájl/mappa menü",
    "Select file range" : "Válasszon fájltartományt",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} / {quota} felhasználva",
    "{used} used" : "{used} felhasználva",
    "\"{name}\" is an invalid file name." : "A(z) „{name}” fájlnév érvénytelen.",
    "File name cannot be empty." : "A fájlnév nem lehet üres.",
    "\"/\" is not allowed inside a file name." : "„/” nem szerepelhet fájlnévben.",
    "\"{name}\" is not an allowed filetype" : "A(z) „{name}” nem engedélyezett fájltípus",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} tárolója megtelt, a fájlok többé nem frissíthetők és szinkronizálhatók.q",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "A(z) „{mountPoint}” csoportmappa megtelt, a fájlok többé nem frissíthetők vagy szinkronizálhatók.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "A(z) „{mountPoint}” külső tároló megtelt, a fájlok többé nem frissíthetők vagy szinkronizálhatók.",
    "Your storage is full, files cannot be updated or synced anymore!" : "A tárhelye megtelt, a fájlok többé nem frissíthetők vagy szinkronizálhatók.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} tárhelye majdnem megtelt ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A(z) \"{mountPoint}\" csoportmappa majdnem megtelt ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A(z) „{mountPoint}” külső tárhely majdnem megtelt ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tárhelye majdnem megtelt ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["megfelel ennek: „{filter}”","megfelel ennek: „{filter}”"],
    "View in folder" : "Megtekintés mappában",
    "Direct link was copied (only works for users who have access to this file/folder)" : "A közvetlen hivatkozás másolva (csak azon felhasználóknak működik, akik elérik ezt a fájlt/mappát)",
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik, akiknek hozzáférése van a fájlhoz/mappához)",
    "You can only favorite a single file or folder at a time" : "Egyszerre csak egy fájlt vagy mappát jelölhet meg kedvencként",
    "New folder" : "Új mappa",
    "Upload file" : "Fájl feltöltése",
    "Recent" : "Legutóbbi",
    "Not favorited" : "Nincs a kedvencek között",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "Added to favorites" : "Hozzáadva a kedvencekhez",
    "Removed from favorites" : "Eltávolítva a kedvencekből",
    "You added {file} to your favorites" : "Hozzáadta a kedvencekhez: {file}",
    "You removed {file} from your favorites" : "Eltávolította a kedvencek közül: {file}",
    "File changes" : "Fájlváltozások",
    "Created by {user}" : "Létrehozta: {user}",
    "Changed by {user}" : "Módosította: {user}",
    "Deleted by {user}" : "Törölte: {user}",
    "Restored by {user}" : "Helyreállította: {user}",
    "Renamed by {user}" : "Átnevezte: {user}",
    "Moved by {user}" : "Áthelyezte: {user}",
    "\"remote user\"" : "„távoli felhasználó”",
    "You created {file}" : "Létrehozta: {file}",
    "You created an encrypted file in {file}" : "Létrehozott egy titkosított fájlt ebben: {file}",
    "{user} created {file}" : "{user} létrehozta: {file}",
    "{user} created an encrypted file in {file}" : "{user} létrehozott egy titkosított fájlt ebben: {file}",
    "{file} was created in a public folder" : "{file} létrehozva egy nyilvános mappában",
    "You changed {file}" : "Módosította: {file}",
    "You changed an encrypted file in {file}" : "Módosított egy titkosított fájlt ebben: {file}",
    "{user} changed {file}" : "{user} módosította: {file}",
    "{user} changed an encrypted file in {file}" : "{user} módosított egy titkosított fájlt ebben: {file}",
    "You deleted {file}" : "Törölte: {file}",
    "You deleted an encrypted file in {file}" : "Törölt egy titkosított fájlt itt: {file}",
    "{user} deleted {file}" : "{user} törölte: {file}",
    "{user} deleted an encrypted file in {file}" : "{user} törölt egy titkosított fájlt itt: {file}",
    "You restored {file}" : "Helyreállította: {file}",
    "{user} restored {file}" : "{user} helyreállította: {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Átnevezte a(z) {oldfile} (rejtett) fájlt a következőre: {newfile} (rejtett)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Átnevezte a(z) {oldfile} (rejtett) fájlt erre: {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Átnevezte a(z) {oldfile} fájlt erre: {newfile} (rejtett)",
    "You renamed {oldfile} to {newfile}" : "Átnevezte a(z) {oldfile} fájlt erre: {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} átnevezte a(z) {oldfile} (rejtett) fájlt erre: {newfile} (rejtett)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} átnevezte a(z) {oldfile} (rejtett) fájlt a következőre: {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} átnevezte a(z) {oldfile} fájlt a következőre: {newfile} (rejtett)",
    "{user} renamed {oldfile} to {newfile}" : "{user} átnevezte a(z) {oldfile} fájlt erre: {newfile}",
    "You moved {oldfile} to {newfile}" : "Áthelyezte a(z) {oldfile} fájlt ide: {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} áthelyezte a(z) {oldfile} fájlt ide: {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Egy fájl eltávolítva vagy hozzáadva a <strong>kedvencekhez</strong>",
    "A file or folder has been <strong>changed</strong>" : "Egy fájl vagy mappa <strong>megváltozott</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Egy kedvenc fájl vagy mappa <strong> megváltozott</strong>",
    "All files" : "Az összes fájl",
    "Upload (max. %s)" : "Feltöltés (legfeljebb %s)",
    "Accept" : "Elfogadás",
    "Reject" : "Elutasítás",
    "Incoming ownership transfer from {user}" : "Bejövő tulajdonjog-átruházás {user} részéről",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Elfogadja a(z) {path} útvonalat?\n\nMegjegyzés: Az átruházási folyamat akár 1 órát is igénybe vehet az elfogadás után.",
    "Ownership transfer failed" : "Tulajdonjog átadása sikertelen",
    "Your ownership transfer of {path} to {user} failed." : "A(z) {path} tulajdonjogának átruházása {user} számára sikertelen.",
    "The ownership transfer of {path} from {user} failed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikertelen.",
    "Ownership transfer done" : "Tulajdonjog átruházása kész",
    "Your ownership transfer of {path} to {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} számára befejeződött.",
    "The ownership transfer of {path} from {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikeres.",
    "in %s" : "itt:  %s",
    "File Management" : "Fájlkezelés",
    "Reload current directory" : "Jelenlegi könyvtár újratöltése",
    "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
    "Select the row for {displayName}" : "A(z) {displayName} sorának kiválasztása",
    "Open folder {name}" : "A(z) {name} mappa megnyitása",
    "Download file {name}" : "A(z) {name} fájl letöltése",
    "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
    "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet sikertelen",
    "Total rows summary" : "Összes sor összegzése",
    "Select all" : "Összes kijelölése",
    "Unselect all" : "Kijelölés megszüntetése",
    "\"{displayName}\" failed on some elements " : "A(z) „{displayName}” sikertelen volt néhány elemen",
    "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
    "ascending" : "növekvő",
    "descending" : "csökkenő",
    "Sort list by {column} ({direction})" : "Lista rendezése {column} alapján ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg, ",
    "Storage informations" : "Tárhely-információk",
    "{usedQuotaByte} used" : "{usedQuotaByte} felhasználva",
    "{relative}% used" : "{relative}% felhasználva",
    "Could not refresh storage stats" : "Nem sikerült frissíteni a tárhelystatisztikákat",
    "Transfer ownership of a file or folder" : "Fájl vagy mappa tulajdonjogának átruházása",
    "Choose file or folder to transfer" : "Válasszon egy fájlt vagy mappát az átruházáshoz",
    "Change" : "Módosítás",
    "New owner" : "Új tulajdonos",
    "Choose a file or folder to transfer" : "Válassz egy átruházandó fájlt vagy mappát",
    "Transfer" : "Átruházás",
    "Transfer {path} to {userid}" : "{path} átruházása {userid} számára",
    "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
    "Unknown error" : "Ismeretlen hiba",
    "Ownership transfer request sent" : "Tulajdonjog átruházási kérés elküldve",
    "Cannot transfer ownership of a file or folder you do not own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
    "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
    "Loading current folder" : "Jelenlegi mappa betöltése",
    "No files in here" : "Itt nincsenek fájlok",
    "No files or folders have been deleted yet" : "Még nem lettek fájlok vagy mappák törölve",
    "Go to the previous folder" : "Ugrás az előző mappához",
    "Go back" : "Visszalépés",
    "Open the files app settings" : "Nyissa meg a Fájlok lalkalmazás beállításait",
    "Files settings" : "Fájlok beállításai",
    "File cannot be accessed" : "A fájl nem érhető el",
    "You might not have have permissions to view it, ask the sender to share it" : "Lehet, hogy nincs jogosultsága, hogy megtekintse, kérje meg a küldőt, hogy ossza meg",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "Crop image previews" : "Kép előnézetek vágása",
    "Additional settings" : "További beállítások",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Másolás a vágólapra",
    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ha engedélyezte a kétfaktoros hitelesítést, akkor kattintson ide, hogy létrehozzon egy új alkalmazásjelszót, és azt használja.",
    "Clipboard is not available" : "A vágólap nem érhető el",
    "WebDAV URL copied to clipboard" : "A WebDAV-cím a vágólapra másolva",
    "Unable to change the favourite state of the file" : "Nem lehet megváltoztatni a fájl kedvenc állapotát",
    "Error while loading the file data" : "Hiba történt a fájladatok betöltése közben",
    "Pick a template for {name}" : "Válassz sablont a(z) {name} fájlnak",
    "Cancel" : "Mégse",
    "Create" : "Létrehozás",
    "Create a new file with the selected template" : "Új fájl létrehozása a kiválasztott sablonnal",
    "Creating file" : "Fájl létrehozása",
    "Blank" : "Üres",
    "Unable to create new file from template" : "Nem lehet új fájlt létrehozni a sablonból",
    "Delete permanently" : "Végleges törlés",
    "Set up templates folder" : "Személyes sablonmappa beállítása",
    "Templates" : "Sablonok",
    "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
    "Toggle %1$s sublist" : "%1$s allista be/ki",
    "Toggle grid view" : "Rácsnézet be/ki",
    "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltölteni próbált fájlok mérete meghaladja a kiszolgálón megengedett legnagyobb méretet.",
    "No favorites yet" : "Még nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
    "Shares" : "Megosztások",
    "Shared with others" : "Megosztva másokkal",
    "Shared with you" : "Megosztva Önnel",
    "Shared by link" : "Megosztva hivatkozással",
    "Deleted shares" : "Törölt megosztások",
    "Pending shares" : "Függőben lévő megosztások",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szövegfájl.txt",
    "Storage invalid" : "A tároló érvénytelen",
    "Select" : "Kiválasztás",
    "You don’t have permission to upload or create files here" : "Nincs jogosultsága fájlok ide feltöltéséhez vagy létrehozásához",
    "New" : "Új",
    "Copied!" : "Másolva!",
    "Unlimited" : "Korlátlan",
    "Search users" : "Fehasználók keresése",
    "Cannot transfer ownership of a file or folder you don't own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
    "%s used" : "%s használt",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "%1$s / %2$s felhasználva",
    "Settings" : "Beállítások",
    "Deleted files" : "Törölt fájlok"
},
"nplurals=2; plural=(n != 1);");
